@@ -432,8 +432,15 @@ extern void
 extern bool	MetaKey;		/* VAR: this terminal has a meta key */
 extern bool	TimeDisplayed;		/* is time actually displayed in modeline? */
 extern char	JoveFeatures[MAXCOLS];	/* VAR: list of compiled-in features */
+
+#if defined(UNIX) || defined(MINGW)
+extern char	JoveCompiled[MAXCOLS];	/* VAR: compile flags used to build this */
+extern char	JoveLinked[MAXCOLS];	/* VAR: link flags used to build this */
+#endif /* UNIX || MINGW */
+
 #ifdef UNIX
 extern int	UpdFreq;		/* VAR: how often to update modeline */
 extern void	SetClockAlarm proto((bool unset));
-#endif
+#endif /* UNIX */
+
 extern bool	SaveOnExit;		/* VAR: offer to save buffers on exit */
