@@ -20,7 +20,7 @@
 #include <windows.h>
 
 INPUT_RECORD in_event[NCHARS], *eventp = in_event;	/* Input events e.g. keyboard, mouse-click */
-int nevents;
+DWORD nevents;
 private HANDLE conin, conout, conerr;	/* Console handles */
 private COORD curpos;
 private COORD maxpos;
@@ -531,7 +531,7 @@ SaveBufferFile(Buffer *b)
 		ofn.lpstrTitle = title;
 		wsprintf(title, "Save Jove buffer `%s' as:", b->b_name);
 
-		getcwd(szDirPath);
+		getcwd(szDirPath, _MAX_PATH-1);
 		ofn.Flags = OFN_SHOWHELP | OFN_OVERWRITEPROMPT |
 			OFN_PATHMUSTEXIST;
 		if (!GetSaveFileName(&ofn))
@@ -606,7 +606,7 @@ int
 /* WIN32 calls aren't cheap, so we buffer output */
 
 private char displaybuf[1024];
-private int bufpos = 0;
+private DWORD bufpos = 0;
 
 /* getLastErrorString is a WIN32 helper function that returns a description
  * of the error code that GetLastError() returns.
@@ -738,6 +738,9 @@ flushscreen()
 		DWORD written;
 
 		CHECK(WriteConsole(conout, displaybuf, bufpos, &written, NULL));
+		if (written != bufpos) {
+			byte_move(displaybuf + written, displaybuf, bufpos - written);
+		}
 		bufpos = 0;
 	}
 }
